pymystem3 package
=================

Environment variables
---------------------
.. envvar:: MYSTEM_BIN

   Path to mystem binary by default. If not set, will use :py:const:`pymystem3.constants.MYSTEM_BIN`.

Submodules
----------

pymystem3.constants module
--------------------------

.. automodule:: pymystem3.constants
    :members:
    :undoc-members:
    :show-inheritance:

pymystem3.metadata module
-------------------------

.. automodule:: pymystem3.metadata
    :members:
    :undoc-members:
    :show-inheritance:

pymystem3.mystem module
-----------------------

.. automodule:: pymystem3.mystem
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pymystem3
    :members:
    :undoc-members:
    :show-inheritance:
